==> crashops_flutter-0.0.824.tar.gz: ios/Classes/CrashOpsPlugin.swift <==
import Flutter
import UIKit
import CrashOps

public class CrashOpsPlugin: NSObject, FlutterPlugin {
  private static let shared = CrashOpsPlugin()

  var previousCrashReports: Array<Any>?

  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "crashops_flutter", binaryMessenger: registrar.messenger())
    let instance = CrashOpsPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)

    CrashOps.shared().previousCrashReports = { (reports) in
        shared.previousCrashReports = reports
    }
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
        case "CrashOps#isEnabled":
            result(CrashOps.shared().isEnabled)
        case "CrashOps#setEnabled":
            if let shouldEnable = call.arguments as? Bool {
                CrashOps.shared().isEnabled = shouldEnable
                result("OK")
            } else {
                result("Failed! Missing boolean argument.")
            }
        case "CrashOps#setMetadata":
            // Append metadata
            if let metadata = call.arguments as? [String: Any] {
                CrashOps.shared().metadata.addEntries(from: metadata)
                result("OK")
            } else {
                result("Failed! Missing dictionary argument.")
            }
        case "CrashOps#setClientId":
            if let clientId = call.arguments as? String {
                CrashOps.shared().clientId = clientId
                result("OK")
            } else {
                result("Failed! Missing String argument for Client ID.")
            }
        case "CrashOps#onFlutterError":
            if let args = call.arguments as? [String: Any] {
                CrashOps.shared().logError(args) // TODO: Add title "Flutter app's error"
                result("OK")
            } else {
                result("Failed! Missing dictionary argument.")
            }
        default:
            print("Unhandled bridged Flutter method call: \(call.method)")
            result("Unhandled method call: \(call.method)")
    }
  }
}

==> crashops_flutter-0.2.1.tar.gz: ios/Classes/CrashOpsPlugin.swift <==
import Flutter
import UIKit
import CrashOps

public class CrashOpsPlugin: NSObject, FlutterPlugin {
  private static let shared = CrashOpsPlugin()

  var previousCrashReports: Array<Any>?

  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "crashops_flutter", binaryMessenger: registrar.messenger())
    let instance = CrashOpsPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)

    CrashOps.shared().previousCrashReports = { (reports) in
        shared.previousCrashReports = reports
    }
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
        case "CrashOps#isEnabled":
            result(CrashOps.shared().isEnabled)
        case "CrashOps#setEnabled":
            if let shouldEnable = call.arguments as? Bool {
                CrashOps.shared().isEnabled = shouldEnable
                result("OK")
            } else {
                result("Failed! Missing boolean argument.")
            }
        case "CrashOps#setMetadata":
            // Append metadata
            if let metadata = call.arguments as? [String: Any] {
                CrashOps.shared().metadata.addEntries(from: metadata)
                result("OK")
            } else {
                result("Failed! Missing dictionary argument.")
            }
        case "CrashOps#setAppKey":
            if let appKey = call.arguments as? String {
                CrashOps.shared().appKey = appKey
                result("OK")
            } else {
                result("Failed! Missing String argument for 'appKey'.")
            }
        case "CrashOps#onFlutterError":
            if let args = call.arguments as? [String: Any] {
                CrashOps.shared().logError(args) // TODO: Add title "Flutter app's error"
                result("OK")
            } else {
                result("Failed! Missing dictionary argument.")
            }
        default:
            print("Unhandled bridged Flutter method call: \(call.method)")
            result("Unhandled method call: \(call.method)")
    }
  }
}
